rnalysis.filtering.FoldChangeFilter.symmetric\_difference
=========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.symmetric_difference